@@ -35,6 +35,7 @@
 #include "tile.h"
 #include "tilelayer.h"
 #include "tileset.h"
+#include "mapobject.h"
 
 using namespace Tiled;
 
@@ -47,7 +48,11 @@ Map::Map(Orientation orientation,
     mHeight(height),
     mTileWidth(tileWidth),
     mTileHeight(tileHeight),
-    mLayerDataFormat(Base64Zlib)
+    mHexSideLength(0),
+    mStaggerAxis(StaggerY),
+    mStaggerIndex(StaggerOdd),
+    mLayerDataFormat(Base64Zlib),
+    mNextObjectId(1)
 {
 }
 
@@ -59,10 +64,14 @@ Map::Map(const Map &map):
     mHeight(map.mHeight),
     mTileWidth(map.mTileWidth),
     mTileHeight(map.mTileHeight),
+    mHexSideLength(map.mHexSideLength),
+    mStaggerAxis(map.mStaggerAxis),
+    mStaggerIndex(map.mStaggerIndex),
     mBackgroundColor(map.mBackgroundColor),
     mDrawMargins(map.mDrawMargins),
     mTilesets(map.mTilesets),
-    mLayerDataFormat(map.mLayerDataFormat)
+    mLayerDataFormat(map.mLayerDataFormat),
+    mNextObjectId(1)
 {
     foreach (const Layer *layer, map.mLayers) {
         Layer *clone = layer->clone();
@@ -176,6 +185,13 @@ void Map::adoptLayer(Layer *layer)
 
     if (TileLayer *tileLayer = layer->asTileLayer())
         adjustDrawMargins(tileLayer->drawMargins());
+
+    if (ObjectGroup *group = layer->asObjectGroup()) {
+        foreach (MapObject *o, group->objects()) {
+            if (o->id() == 0)
+                o->setId(takeNextObjectId());
+        }
+    }
 }
 
 Layer *Map::takeLayerAt(int index)
@@ -226,6 +242,48 @@ bool Map::isTilesetUsed(Tileset *tileset) const
 }
 
 
+QString Tiled::staggerAxisToString(Map::StaggerAxis staggerAxis)
+{
+    switch (staggerAxis) {
+    default:
+    case Map::StaggerY:
+        return QLatin1String("y");
+        break;
+    case Map::StaggerX:
+        return QLatin1String("x");
+        break;
+    }
+}
+
+Map::StaggerAxis Tiled::staggerAxisFromString(const QString &string)
+{
+    Map::StaggerAxis staggerAxis = Map::StaggerY;
+    if (string == QLatin1String("x"))
+        staggerAxis = Map::StaggerX;
+    return staggerAxis;
+}
+
+QString Tiled::staggerIndexToString(Map::StaggerIndex staggerIndex)
+{
+    switch (staggerIndex) {
+    default:
+    case Map::StaggerOdd:
+        return QLatin1String("odd");
+        break;
+    case Map::StaggerEven:
+        return QLatin1String("even");
+        break;
+    }
+}
+
+Map::StaggerIndex Tiled::staggerIndexFromString(const QString &string)
+{
+    Map::StaggerIndex staggerIndex = Map::StaggerOdd;
+    if (string == QLatin1String("even"))
+        staggerIndex = Map::StaggerEven;
+    return staggerIndex;
+}
+
 QString Tiled::orientationToString(Map::Orientation orientation)
 {
     switch (orientation) {
@@ -242,6 +300,9 @@ QString Tiled::orientationToString(Map::Orientation orientation)
     case Map::Staggered:
         return QLatin1String("staggered");
         break;
+    case Map::Hexagonal:
+        return QLatin1String("hexagonal");
+        break;
     }
 }
 
@@ -254,6 +315,8 @@ Map::Orientation Tiled::orientationFromString(const QString &string)
         orientation = Map::Isometric;
     } else if (string == QLatin1String("staggered")) {
         orientation = Map::Staggered;
+    } else if (string == QLatin1String("hexagonal")) {
+        orientation = Map::Hexagonal;
     }
     return orientation;
 }
