@@ -105,21 +105,23 @@ CellRenderer::CellRenderer(QPainter *painter)
  * For performance reasons, the actual drawing is delayed until a different
  * kind of tile has to be drawn. For this reason it is necessary to call
  * flush when finished doing drawCell calls. This function is also called by
- * the destructor so usually an explicit call it not needed.
+ * the destructor so usually an explicit call is not needed.
  */
-void CellRenderer::render(const Cell &cell, const QPointF &pos, Origin origin)
+void CellRenderer::render(const Cell &cell, const QPointF &pos, const QSizeF &cellSize, Origin origin)
 {
     if (mTile != cell.tile)
         flush();
 
     const QPixmap &image = cell.tile->currentFrameImage();
     const QSizeF size = image.size();
+    const QSizeF objectSize = (cellSize == QSizeF(0,0)) ? size : cellSize;
+    const QSizeF scale(objectSize.width() / size.width(), objectSize.height() / size.height());
     const QPoint offset = cell.tile->tileset()->tileOffset();
-    const QPointF sizeHalf = QPointF(size.width() / 2, size.height() / 2);
+    const QPointF sizeHalf = QPointF(objectSize.width() / 2, objectSize.height() / 2);
 
     QPainter::PixmapFragment fragment;
-    fragment.x = pos.x() + offset.x() + sizeHalf.x();
-    fragment.y = pos.y() + offset.y() + sizeHalf.y() - size.height();
+    fragment.x = pos.x() + (offset.x() * scale.width()) + sizeHalf.x();
+    fragment.y = pos.y() + (offset.y() * scale.height()) + sizeHalf.y() - objectSize.height();
     fragment.sourceLeft = 0;
     fragment.sourceTop = 0;
     fragment.width = size.width();
@@ -128,14 +130,18 @@ void CellRenderer::render(const Cell &cell, const QPointF &pos, Origin origin)
     fragment.scaleY = cell.flippedVertically ? -1 : 1;
     fragment.rotation = 0;
     fragment.opacity = 1;
+    
+    bool flippedHorizontally = cell.flippedHorizontally;
+    bool flippedVertically = cell.flippedVertically;
 
     if (origin == BottomCenter)
         fragment.x -= sizeHalf.x();
 
     if (cell.flippedAntiDiagonally) {
         fragment.rotation = 90;
-        fragment.scaleX *= -1;
-        std::swap(fragment.scaleX, fragment.scaleY);
+        
+        flippedHorizontally = cell.flippedVertically;
+        flippedVertically = !cell.flippedHorizontally;
 
         // Compensate for the swap of image dimensions
         const qreal halfDiff = sizeHalf.y() - sizeHalf.x();
@@ -143,6 +149,9 @@ void CellRenderer::render(const Cell &cell, const QPointF &pos, Origin origin)
         if (origin != BottomCenter)
             fragment.x += halfDiff;
     }
+    
+    fragment.scaleX = scale.width() * (flippedHorizontally ? -1 : 1);
+    fragment.scaleY = scale.height() * (flippedVertically ? -1 : 1);
 
     if (mIsOpenGL || (fragment.scaleX > 0 && fragment.scaleY > 0)) {
         mTile = cell.tile;
