@@ -66,10 +66,13 @@ QRectF OrthogonalRenderer::boundingRect(const MapObject *object) const
         const Tile *tile = object->cell().tile;
         const QSize imgSize = tile->image().size();
         const QPoint tileOffset = tile->tileset()->tileOffset();
-        boundingRect = QRectF(bottomLeft.x() + tileOffset.x(),
-                              bottomLeft.y() + tileOffset.y() - imgSize.height(),
-                              imgSize.width(),
-                              imgSize.height()).adjusted(-1, -1, 1, 1);
+        const QSizeF objectSize = object->size();
+        const QSizeF scale(objectSize.width() / imgSize.width(), objectSize.height() / imgSize.height());
+
+        boundingRect = QRectF(bottomLeft.x() + (tileOffset.x() * scale.width()),
+                              bottomLeft.y() + (tileOffset.y() * scale.height()) - objectSize.height(),
+                              objectSize.width(),
+                              objectSize.height()).adjusted(-1, -1, 1, 1);
     } else {
         const qreal extraSpace = qMax(objectLineWidth() / 2, qreal(1));
 
@@ -82,9 +85,8 @@ QRectF OrthogonalRenderer::boundingRect(const MapObject *object) const
                                                10 + extraSpace + 1,
                                                10 + extraSpace + 1);
             } else {
-                const int nameHeight = object->name().isEmpty() ? 0 : 15;
                 boundingRect = bounds.adjusted(-extraSpace,
-                                               -nameHeight - extraSpace,
+                                               -extraSpace,
                                                extraSpace + 1,
                                                extraSpace + 1);
             }
@@ -270,6 +272,7 @@ void OrthogonalRenderer::drawTileLayer(QPainter *painter,
 
             renderer.render(cell,
                             QPointF(x * tileWidth, (y + 1) * tileHeight),
+                            QSizeF(0, 0),
                             CellRenderer::BottomLeft);
         }
     }
@@ -306,7 +309,7 @@ void OrthogonalRenderer::drawMapObject(QPainter *painter,
     const Cell &cell = object->cell();
 
     if (!cell.isEmpty()) {
-        CellRenderer(painter).render(cell, QPointF(),
+        CellRenderer(painter).render(cell, QPointF(), object->size(),
                                      CellRenderer::BottomLeft);
 
         if (testFlag(ShowTileObjectOutlines)) {
@@ -358,22 +361,13 @@ void OrthogonalRenderer::drawMapObject(QPainter *painter,
             if (rect.isNull())
                 rect = QRectF(QPointF(-10, -10), QSizeF(20, 20));
 
-            const QFontMetrics fm = painter->fontMetrics();
-            QString name = fm.elidedText(object->name(), Qt::ElideRight,
-                                         rect.width() + 2);
-
             // Draw the shadow
             painter->setPen(shadowPen);
             painter->drawRect(rect.translated(shadowOffset));
-            if (!name.isEmpty())
-                painter->drawText(QPointF(0, -4 - lineWidth / 2) + shadowOffset, name);
 
             painter->setPen(linePen);
             painter->setBrush(fillBrush);
             painter->drawRect(rect);
-            if (!name.isEmpty())
-                painter->drawText(QPointF(0, -4 - lineWidth / 2), name);
-
             break;
         }
 
@@ -405,22 +399,13 @@ void OrthogonalRenderer::drawMapObject(QPainter *painter,
             if (rect.isNull())
                 rect = QRectF(QPointF(-10, -10), QSizeF(20, 20));
 
-            const QFontMetrics fm = painter->fontMetrics();
-            QString name = fm.elidedText(object->name(), Qt::ElideRight,
-                                         rect.width() + 2);
-
             // Draw the shadow
             painter->setPen(shadowPen);
             painter->drawEllipse(rect.translated(shadowOffset));
-            if (!name.isEmpty())
-                painter->drawText(QPoint(1, -5 + 1), name);
 
             painter->setPen(linePen);
             painter->setBrush(fillBrush);
             painter->drawEllipse(rect);
-            if (!name.isEmpty())
-                painter->drawText(QPoint(0, -5), name);
-
             break;
         }
         }
