@@ -200,7 +200,7 @@ static bool includeTile(const Tile *tile)
         return true;
     if (tile->terrain() != 0xFFFFFFFF)
         return true;
-    if (tile->terrainProbability() != -1.f)
+    if (tile->terrainProbability() != 1.f)
         return true;
 
     return false;
@@ -295,7 +295,7 @@ void LuaPlugin::writeTileset(LuaTableWriter &writer, const Tileset *tileset,
             writer.setSuppressNewlines(false);
         }
 
-        if (tile->terrainProbability() != -1.f)
+        if (tile->terrainProbability() != 1.f)
             writer.writeKeyAndValue("probability", tile->terrainProbability());
 
         if (ObjectGroup *objectGroup = tile->objectGroup())
