@@ -29,7 +29,7 @@
 #include "mapscene.h"
 #include "objectgroup.h"
 #include "objectgroupitem.h"
-#include "preferences.h"
+#include "snaphelper.h"
 #include "tile.h"
 #include "utils.h"
 
@@ -73,7 +73,7 @@ void CreateObjectTool::keyPressed(QKeyEvent *event)
     case Qt::Key_Enter:
     case Qt::Key_Return:
         if (mNewMapObjectItem) {
-                finishNewMapObject();
+            finishNewMapObject();
             return;
         }
         break;
@@ -97,29 +97,14 @@ void CreateObjectTool::mouseMoved(const QPointF &pos,
 {
     AbstractObjectTool::mouseMoved(pos, modifiers);
 
-    if (mNewMapObjectItem){
-        bool snapToGrid = Preferences::instance()->snapToGrid();
-        bool snapToFineGrid = Preferences::instance()->snapToFineGrid();
-        if (modifiers & Qt::ControlModifier) {
-            snapToGrid = !snapToGrid;
-            snapToFineGrid = false;
-        }
-
-        mouseMovedWhileCreatingObject(pos, modifiers, snapToGrid, snapToFineGrid);
-    }
+    if (mNewMapObjectItem)
+        mouseMovedWhileCreatingObject(pos, modifiers);
 }
 
 void CreateObjectTool::mousePressed(QGraphicsSceneMouseEvent *event)
 {
-    bool snapToGrid = Preferences::instance()->snapToGrid();
-    bool snapToFineGrid = Preferences::instance()->snapToFineGrid();
-    if (event->modifiers() & Qt::ControlModifier) {
-        snapToGrid = !snapToGrid;
-        snapToFineGrid = false;
-    }
-
-    if(mNewMapObjectItem){
-        mousePressedWhileCreatingObject(event, snapToGrid, snapToFineGrid);
+    if (mNewMapObjectItem) {
+        mousePressedWhileCreatingObject(event);
         return;
     }
 
@@ -133,7 +118,7 @@ void CreateObjectTool::mousePressed(QGraphicsSceneMouseEvent *event)
         return;
 
     const MapRenderer *renderer = mapDocument()->renderer();
-    QPointF tileCoords;
+    QPointF pixelCoords;
 
     /*TODO: calculate the tile offset with a polymorphic behaviour object
      * that is instantiated by the correspondend ObjectTool
@@ -143,34 +128,20 @@ void CreateObjectTool::mousePressed(QGraphicsSceneMouseEvent *event)
             return;
 
         const QPointF diff(-mTile->width() / 2, mTile->height() / 2);
-        tileCoords = renderer->screenToTileCoords(event->scenePos() + diff);
+        pixelCoords = renderer->screenToPixelCoords(event->scenePos() + diff);
     } else {
-        tileCoords = renderer->screenToTileCoords(event->scenePos());
+        pixelCoords = renderer->screenToPixelCoords(event->scenePos());
     }
 
-        if (snapToFineGrid) {
-        int gridFine = Preferences::instance()->gridFine();
-        tileCoords = (tileCoords * gridFine).toPoint();
-        tileCoords /= gridFine;
-    } else if (snapToGrid)
-        tileCoords = tileCoords.toPoint();
-    
-    const QPointF pixelCoords = renderer->tileToPixelCoords(tileCoords);
+    SnapHelper(renderer, event->modifiers()).snap(pixelCoords);
 
     startNewMapObject(pixelCoords, objectGroup);
 }
 
 void CreateObjectTool::mouseReleased(QGraphicsSceneMouseEvent *event)
 {
-    bool snapToGrid = Preferences::instance()->snapToGrid();
-    bool snapToFineGrid = Preferences::instance()->snapToFineGrid();
-    if (event->modifiers() & Qt::ControlModifier) {
-        snapToGrid = !snapToGrid;
-        snapToFineGrid = false;
-    }
-    if (mNewMapObjectItem){
-        mouseReleasedWhileCreatingObject(event, snapToGrid, snapToFineGrid);
-    }
+    if (mNewMapObjectItem)
+        mouseReleasedWhileCreatingObject(event);
 }
 
 void CreateObjectTool::startNewMapObject(const QPointF &pos,
@@ -226,17 +197,17 @@ void CreateObjectTool::finishNewMapObject()
                                                       newMapObject));
 }
 
-void CreateObjectTool::mouseMovedWhileCreatingObject(const QPointF &, Qt::KeyboardModifiers, bool, bool)
+void CreateObjectTool::mouseMovedWhileCreatingObject(const QPointF &, Qt::KeyboardModifiers)
 {
-   //optional override
+    // optional override
 }
 
-void CreateObjectTool::mousePressedWhileCreatingObject(QGraphicsSceneMouseEvent *, bool, bool)
+void CreateObjectTool::mousePressedWhileCreatingObject(QGraphicsSceneMouseEvent *)
 {
-    //optional override
+    // optional override
 }
 
-void CreateObjectTool::mouseReleasedWhileCreatingObject(QGraphicsSceneMouseEvent *, bool, bool)
+void CreateObjectTool::mouseReleasedWhileCreatingObject(QGraphicsSceneMouseEvent *)
 {
-    //optional override
+    // optional override
 }
