@@ -29,9 +29,9 @@
 #include "mapobjectitem.h"
 #include "maprenderer.h"
 #include "mapscene.h"
-#include "preferences.h"
 #include "rangeset.h"
 #include "selectionrectangle.h"
+#include "snaphelper.h"
 #include "utils.h"
 
 #include <QApplication>
@@ -519,24 +519,16 @@ void EditPolygonTool::updateMovingItems(const QPointF &pos,
     MapRenderer *renderer = mapDocument()->renderer();
     QPointF diff = pos - mStart;
 
-    bool snapToGrid = Preferences::instance()->snapToGrid();
-    bool snapToFineGrid = Preferences::instance()->snapToFineGrid();
-    if (modifiers & Qt::ControlModifier) {
-        snapToGrid = !snapToGrid;
-        snapToFineGrid = false;
-    }
+    SnapHelper snapHelper(renderer, modifiers);
 
-    if (snapToGrid || snapToFineGrid) {
-        int scale = snapToFineGrid ? Preferences::instance()->gridFine() : 1;
-        const QPointF alignScreenPos =
-                renderer->pixelToScreenCoords(mAlignPosition);
-        const QPointF newAlignPixelPos = alignScreenPos + diff;
+    if (snapHelper.snaps()) {
+        const QPointF alignScreenPos = renderer->pixelToScreenCoords(mAlignPosition);
+        const QPointF newAlignScreenPos = alignScreenPos + diff;
 
-        // Snap the position to the grid
-        QPointF newTileCoords =
-                (renderer->screenToTileCoords(newAlignPixelPos) * scale).toPoint();
-        newTileCoords /= scale;
-        diff = renderer->tileToScreenCoords(newTileCoords) - alignScreenPos;
+        QPointF newAlignPixelPos = renderer->screenToPixelCoords(newAlignScreenPos);
+        snapHelper.snap(newAlignPixelPos);
+
+        diff = renderer->pixelToScreenCoords(newAlignPixelPos) - alignScreenPos;
     }
 
     int i = 0;
@@ -654,8 +646,8 @@ void EditPolygonTool::deleteNodes()
             // We've removed the entire object
             undoStack->push(new RemoveMapObject(mapDocument(), object));
         } else {
-            object->setPolygon(newPolygon);
             undoStack->push(new ChangePolygon(mapDocument(), object,
+                                              newPolygon,
                                               oldPolygon));
         }
     }
@@ -810,8 +802,8 @@ void EditPolygonTool::joinNodes()
                 macroStarted = true;
             }
 
-            object->setPolygon(newPolygon);
             undoStack->push(new ChangePolygon(mapDocument(), object,
+                                              newPolygon,
                                               oldPolygon));
         }
     }
@@ -846,8 +838,8 @@ void EditPolygonTool::splitSegments()
                 macroStarted = true;
             }
 
-            object->setPolygon(newPolygon);
             undoStack->push(new ChangePolygon(mapDocument(), object,
+                                              newPolygon,
                                               oldPolygon));
         }
     }
