@@ -65,6 +65,7 @@ private:
     void justQuit();
     void setDisableOpenGL();
     void setExportMap();
+    void showExportFormats();
 
     // Convenience wrapper around registerOption
     template <void (CommandLineHandler::*memberFunction)()>
@@ -107,6 +108,11 @@ CommandLineHandler::CommandLineHandler()
                 QChar(),
                 QLatin1String("--export-map"),
                 QLatin1String("Export the specified tmx file to target"));
+
+    option<&CommandLineHandler::showExportFormats>(
+                QChar(),
+                QLatin1String("--export-formats"),
+                QLatin1String("Print a list of supported export formats"));
 }
 
 void CommandLineHandler::showVersion()
@@ -134,6 +140,21 @@ void CommandLineHandler::setExportMap()
     exportMap = true;
 }
 
+void CommandLineHandler::showExportFormats()
+{
+    PluginManager *pluginManager = PluginManager::instance();
+    pluginManager->loadPlugins();
+
+    qWarning() << "Export formats:";
+    QList<Tiled::MapWriterInterface*> writers = pluginManager->interfaces<Tiled::MapWriterInterface>();
+    foreach (Tiled::MapWriterInterface *writer, writers) {
+        foreach (const QString &filter, writer->nameFilters())
+            qWarning() << " " << filter;
+    }
+
+    quit = true;
+}
+
 int main(int argc, char *argv[])
 {
     /*
@@ -152,7 +173,7 @@ int main(int argc, char *argv[])
 #ifdef BUILD_INFO_VERSION
     a.setApplicationVersion(QLatin1String(AS_STRING(BUILD_INFO_VERSION)));
 #else
-    a.setApplicationVersion(QLatin1String("0.11.0"));
+    a.setApplicationVersion(QLatin1String("0.12.3"));
 #endif
 
 #ifdef Q_OS_MAC
