@@ -87,11 +87,6 @@ public:
      */
     void resizeObject(const QSizeF &size);
 
-    /**
-     * Sets the rotation of the associated map object.
-     */
-    void setObjectRotation(qreal angle);
-
     /**
      * Sets a new polygon on the associated object.
      */
@@ -119,10 +114,6 @@ private:
     QColor mColor;      // Cached color of the object
     bool mIsEditable;
     bool mSyncing;
-    ResizeHandle *mResizeHandle;
-
-    friend class Handle;
-    friend class ResizeHandle;
 };
 
 } // namespace Internal
