@@ -125,6 +125,8 @@ void MapScene::setMapDocument(MapDocument *mapDocument)
                 this, SLOT(mapChanged()));
         connect(mMapDocument, SIGNAL(regionChanged(QRegion)),
                 this, SLOT(repaintRegion(QRegion)));
+        connect(mMapDocument, SIGNAL(tileLayerDrawMarginsChanged(TileLayer*)),
+                this, SLOT(tileLayerDrawMarginsChanged(TileLayer*)));
         connect(mMapDocument, SIGNAL(layerAdded(int)),
                 this, SLOT(layerAdded(int)));
         connect(mMapDocument, SIGNAL(layerRemoved(int)),
@@ -218,7 +220,7 @@ QGraphicsItem *MapScene::createLayerItem(Layer *layer)
     QGraphicsItem *layerItem = 0;
 
     if (TileLayer *tl = layer->asTileLayer()) {
-        layerItem = new TileLayerItem(tl, mMapDocument->renderer());
+        layerItem = new TileLayerItem(tl, mMapDocument);
     } else if (ObjectGroup *og = layer->asObjectGroup()) {
         const ObjectGroup::DrawOrder drawOrder = og->drawOrder();
         ObjectGroupItem *ogItem = new ObjectGroupItem(og);
@@ -236,7 +238,7 @@ QGraphicsItem *MapScene::createLayerItem(Layer *layer)
         }
         layerItem = ogItem;
     } else if (ImageLayer *il = layer->asImageLayer()) {
-        layerItem = new ImageLayerItem(il, mMapDocument->renderer());
+        layerItem = new ImageLayerItem(il, mMapDocument);
     }
 
     Q_ASSERT(layerItem);
@@ -324,7 +326,8 @@ void MapScene::currentLayerIndexChanged()
 }
 
 /**
- * Adapts the scene rect and layers to the new map size.
+ * Adapts the scene, layers and objects to new map size, orientation or
+ * background color.
  */
 void MapScene::mapChanged()
 {
@@ -337,6 +340,9 @@ void MapScene::mapChanged()
             tli->syncWithTileLayer();
     }
 
+    foreach (MapObjectItem *item, mObjectItems)
+        item->syncWithMapObject();
+
     const Map *map = mMapDocument->map();
     if (map->backgroundColor().isValid())
         setBackgroundBrush(map->backgroundColor());
@@ -353,6 +359,13 @@ void MapScene::tilesetChanged(Tileset *tileset)
         update();
 }
 
+void MapScene::tileLayerDrawMarginsChanged(TileLayer *tileLayer)
+{
+    const int index = mMapDocument->map()->layers().indexOf(tileLayer);
+    TileLayerItem *item = static_cast<TileLayerItem*>(mLayerItems.at(index));
+    item->syncWithTileLayer();
+}
+
 void MapScene::layerAdded(int index)
 {
     Layer *layer = mMapDocument->map()->layerAt(index);
