@@ -114,6 +114,7 @@ TileCollisionEditor::TileCollisionEditor(QWidget *parent)
     QShortcut *copyShortcut = new QShortcut(QKeySequence::Copy, this);
     QShortcut *pasteShortcut = new QShortcut(QKeySequence::Paste, this);
     QShortcut *deleteShortcut = new QShortcut(QKeySequence::Delete, this);
+    QShortcut *deleteShortcut2 = new QShortcut(QKeySequence(Qt::Key_Backspace), this);
 
     connect(undoShortcut, SIGNAL(activated()), SLOT(undo()));
     connect(redoShortcut, SIGNAL(activated()), SLOT(redo()));
@@ -121,6 +122,7 @@ TileCollisionEditor::TileCollisionEditor(QWidget *parent)
     connect(copyShortcut, SIGNAL(activated()), SLOT(copy()));
     connect(pasteShortcut, SIGNAL(activated()), SLOT(paste()));
     connect(deleteShortcut, SIGNAL(activated()), SLOT(delete_()));
+    connect(deleteShortcut2, SIGNAL(activated()), SLOT(delete_()));
 
     retranslateUi();
     resize(300, 300);
