@@ -28,6 +28,7 @@
 
 #include "tmxrasterizer.h"
 
+#include "hexagonalrenderer.h"
 #include "imagelayer.h"
 #include "isometricrenderer.h"
 #include "map.h"
@@ -88,6 +89,9 @@ int TmxRasterizer::render(const QString &mapFileName,
     case Map::Staggered:
         renderer = new StaggeredRenderer(map);
         break;
+    case Map::Hexagonal:
+        renderer = new HexagonalRenderer(map);
+        break;
     case Map::Orthogonal:
     default:
         renderer = new OrthogonalRenderer(map);
